agentle.mcp.resources.binary\_resources.base64\_convertible
===========================================================

.. automodule:: agentle.mcp.resources.binary_resources.base64_convertible

   
   .. rubric:: Classes

   .. autosummary::
   
      Base64Convertible
   